@@ -12,7 +12,7 @@ from pprint import pprint
 from oauth2client.service_account import ServiceAccountCredentials
 
 
-class SpreadSheetDB():
+class EasySpreadsheet():
     
     def __init__(self, auth_json: dict, spreadsheet_id: str, sheet_name: str):
 
